@@ -2,6 +2,7 @@ package Minion;
 use Mojo::Base 'Mojo::EventEmitter';
 
 use Carp 'croak';
+use Config;
 use Minion::Job;
 use Minion::Worker;
 use Mojo::Loader 'load_class';
@@ -15,7 +16,7 @@ has missing_after => 1800;
 has remove_after  => 172800;
 has tasks         => sub { {} };
 
-our $VERSION = '5.09';
+our $VERSION = '6.0';
 
 sub add_task { ($_[0]->tasks->{$_[1]} = $_[2]) and return $_[0] }
 
@@ -66,6 +67,10 @@ sub stats { shift->backend->stats }
 
 sub worker {
   my $self = shift;
+
+  # No fork emulation support
+  croak 'Minion workers do not support fork emulation' if $Config{d_pseudofork};
+
   my $worker = Minion::Worker->new(minion => $self);
   $self->emit(worker => $worker);
   return $worker;
@@ -121,8 +126,9 @@ Minion - Job queue
 L<Minion> is a job queue for the L<Mojolicious|http://mojolicious.org> real-time
 web framework, with support for multiple named queues, priorities, delayed jobs,
 job dependencies, job results, retries with backoff, statistics, distributed
-workers, parallel processing, autoscaling, resource leak protection and multiple
-backends (such as L<PostgreSQL|http://www.postgresql.org>).
+workers, parallel processing, autoscaling, remote control, resource leak
+protection and multiple backends (such as
+L<PostgreSQL|http://www.postgresql.org>).
 
 Job queues allow you to process time and/or computationally intensive tasks in
 background processes, outside of the request/response lifecycle. Among those
