@@ -5,6 +5,7 @@ use Carp 'croak';
 
 has 'minion';
 
+sub broadcast    { croak 'Method "broadcast" not implemented by subclass' }
 sub dequeue      { croak 'Method "dequeue" not implemented by subclass' }
 sub enqueue      { croak 'Method "enqueue" not implemented by subclass' }
 sub fail_job     { croak 'Method "fail_job" not implemented by subclass' }
@@ -12,6 +13,7 @@ sub finish_job   { croak 'Method "finish_job" not implemented by subclass' }
 sub job_info     { croak 'Method "job_info" not implemented by subclass' }
 sub list_jobs    { croak 'Method "list_jobs" not implemented by subclass' }
 sub list_workers { croak 'Method "list_workers" not implemented by subclass' }
+sub receive      { croak 'Method "receive" not implemented by subclass' }
 
 sub register_worker {
   croak 'Method "register_worker" not implemented by subclass';
@@ -42,6 +44,7 @@ Minion::Backend - Backend base class
   package Minion::Backend::MyBackend;
   use Mojo::Base 'Minion::Backend';
 
+  sub broadcast         {...}
   sub dequeue           {...}
   sub enqueue           {...}
   sub fail_job          {...}
@@ -49,6 +52,7 @@ Minion::Backend - Backend base class
   sub job_info          {...}
   sub list_jobs         {...}
   sub list_workers      {...}
+  sub receive           {...}
   sub register_worker   {...}
   sub remove_job        {...}
   sub repair            {...}
@@ -79,6 +83,14 @@ L<Minion> object this backend belongs to.
 L<Minion::Backend> inherits all methods from L<Mojo::Base> and implements the
 following new ones.
 
+=head2 broadcast
+
+  my $bool = $backend->broadcast('some_command');
+  my $bool = $backend->broadcast('some_command', [@args]);
+  my $bool = $backend->broadcast('some_command', [@args], [$id1, $id2, $id3]);
+
+Broadcast remote control command to one or more workers.
+
 =head2 dequeue
 
   my $job_info = $backend->dequeue($worker_id, 0.5);
@@ -351,6 +363,12 @@ List only jobs for this task.
 Returns the same information as L</"worker_info"> but in batches. Meant to be
 overloaded in a subclass.
 
+=head2 receive
+
+  my $commands = $backend->receive($worker_id);
+
+Receive remote control commands for worker.
+
 =head2 register_worker
 
   my $worker_id = $backend->register_worker;
