@@ -8,6 +8,14 @@ use Sys::Hostname 'hostname';
 
 has 'pg';
 
+sub broadcast {
+  my ($self, $command, $args, $ids) = (shift, shift, shift || [], shift || []);
+  return !!$self->pg->db->query(
+    q{update minion_workers set inbox = inbox || $1::jsonb
+      where (id = any($2) or $2 = '{}')}, {json => [[$command, @$args]]}, $ids
+  )->rows;
+}
+
 sub dequeue {
   my ($self, $id, $wait, $options) = @_;
 
@@ -85,6 +93,16 @@ sub new {
   return $self;
 }
 
+sub receive {
+  my $array = shift->pg->db->query(
+    "update minion_workers as new set inbox = '[]'
+     from (select id, inbox from minion_workers where id = ? for update) as old
+     where new.id = old.id and old.inbox != '[]'
+     returning old.inbox", shift
+  )->expand->array;
+  return $array ? $array->[0] : [];
+}
+
 sub register_worker {
   my ($self, $id) = @_;
 
@@ -211,7 +229,7 @@ sub _try {
        where delayed <= now() and (parents = '{}' or cardinality(parents) = (
          select count(*) from minion_jobs
          where id = any(j.parents) and state = 'finished'
-       )) and queue = any (?) and state = 'inactive' and task = any (?)
+       )) and queue = any(?) and state = 'inactive' and task = any(?)
        order by priority desc, id
        limit 1
        for update skip locked
@@ -276,6 +294,14 @@ L<Mojo::Pg> object used to store all data.
 L<Minion::Backend::Pg> inherits all methods from L<Minion::Backend> and
 implements the following new ones.
 
+=head2 broadcast
+
+  my $bool = $backend->broadcast('some_command');
+  my $bool = $backend->broadcast('some_command', [@args]);
+  my $bool = $backend->broadcast('some_command', [@args], [$id1, $id2, $id3]);
+
+Broadcast remote control command to one or more workers.
+
 =head2 dequeue
 
   my $job_info = $backend->dequeue($worker_id, 0.5);
@@ -549,6 +575,12 @@ Returns the same information as L</"worker_info"> but in batches.
 
 Construct a new L<Minion::Backend::Pg> object.
 
+=head2 receive
+
+  my $commands = $backend->receive($worker_id);
+
+Receive remote control commands for worker.
+
 =head2 register_worker
 
   my $worker_id = $backend->register_worker;
@@ -808,7 +840,11 @@ drop trigger if exists minion_jobs_notify_workers_trigger on minion_jobs;
 drop function if exists minion_jobs_notify_workers();
 
 -- 10 up
-alter table minion_jobs add column parents bigint[] default '{}'::bigint[];
+alter table minion_jobs add column parents bigint[] default '{}';
 
 -- 11 up
 create index on minion_jobs (state, priority desc, id);
+
+-- 12 up
+alter table minion_workers add column inbox jsonb
+  check(jsonb_typeof(inbox) = 'array') default '[]';
