@@ -11,24 +11,28 @@ sub run {
   my ($self, @args) = @_;
 
   GetOptionsFromArray \@args,
-    'I|heartbeat-interval=i' => \($self->{hearthbeat} = 60),
-    'j|jobs=i'               => \($self->{max}        = 4),
+    'C|command-interval=i'   => \($self->{commands}  = 10),
+    'I|heartbeat-interval=i' => \($self->{heartbeat} = 60),
+    'j|jobs=i'               => \($self->{max}       = 4),
     'q|queue=s'              => \my @queues,
-    'R|repair-interval=i'    => \($self->{repair}     = 21600);
+    'R|repair-interval=i'    => \($self->{repair}    = 21600);
   $self->{queues} = @queues ? \@queues : ['default'];
 
   local $SIG{CHLD} = 'DEFAULT';
   local $SIG{INT} = local $SIG{TERM} = sub { $self->{finished}++ };
   local $SIG{QUIT}
     = sub { ++$self->{finished} and kill 'KILL', keys %{$self->{jobs}} };
-  local $SIG{TTIN} = sub { $self->{max}++ };
-  local $SIG{TTOU} = sub { $self->{max}-- if $self->{max} > 0 };
-  local $SIG{USR1} = sub { $self->{max} = 0 };
+
+  # Remote control commands need to validate arguments carefully
+  my $app = $self->app;
+  my $worker = $self->{worker} = $app->minion->worker;
+  $worker->add_command(
+    jobs => sub { $self->{max} = $_[1] if ($_[1] // '') =~ /^\d+$/ });
+  $worker->add_command(
+    stop => sub { $self->{jobs}{$_[1]}->stop if $self->{jobs}{$_[1] // ''} });
 
   # Log fatal errors
-  my $app = $self->app;
   $app->log->debug("Worker $$ started");
-  my $worker = $self->{worker} = $app->minion->worker;
   eval { $self->_work until $self->{finished} && !keys %{$self->{jobs}}; 1 }
     or $app->log->fatal("Worker error: $@");
   $worker->unregister;
@@ -39,8 +43,12 @@ sub _work {
 
   # Send heartbeats in regular intervals
   my $worker = $self->{worker};
-  $worker->register and $self->{register} = steady_time + $self->{hearthbeat}
-    if ($self->{register} || 0) < steady_time;
+  $worker->register and $self->{lr} = steady_time + $self->{heartbeat}
+    if ($self->{lr} || 0) < steady_time;
+
+  # Process worker remote control commands in regular intervals
+  $worker->process_commands and $self->{lp} = steady_time + $self->{commands}
+    if ($self->{lp} || 0) < steady_time;
 
   # Repair in regular intervals (randomize to avoid congestion)
   if (($self->{check} || 0) < steady_time) {
@@ -53,15 +61,15 @@ sub _work {
 
   # Check if jobs are finished
   my $jobs = $self->{jobs} ||= {};
-  $jobs->{$_}->is_finished($_) and delete $jobs->{$_} for keys %$jobs;
+  $jobs->{$_}->is_finished and delete $jobs->{$_} for keys %$jobs;
 
   # Wait if job limit has been reached or worker is stopping
   if (($self->{max} <= keys %$jobs) || $self->{finished}) { sleep 1 }
 
   # Try to get more jobs
   elsif (my $job = $worker->dequeue(5 => {queues => $self->{queues}})) {
-    $jobs->{my $pid = $job->start} = $job;
-    my ($id, $task) = ($job->id, $job->task);
+    $jobs->{my $id = $job->id} = $job->start;
+    my ($pid, $task) = ($job->pid, $job->task);
     $self->app->log->debug(
       qq{Performing job "$id" with task "$task" in process $pid});
   }
@@ -80,10 +88,12 @@ Minion::Command::minion::worker - Minion worker command
   Usage: APPLICATION minion worker [OPTIONS]
 
     ./myapp.pl minion worker
-    ./myapp.pl minion worker -m production -I 15 -R 3600 -j 10
+    ./myapp.pl minion worker -m production -I 15 -C 5 -R 3600 -j 10
     ./myapp.pl minion worker -q important -q default
 
   Options:
+    -C, --command-interval <seconds>     Worker remote control command interval,
+                                         defaults to 10
     -h, --help                           Show this summary of available options
         --home <path>                    Path to home directory of your
                                          application, defaults to the value of
@@ -117,19 +127,26 @@ Stop gracefully after finishing the current jobs.
 
 Stop immediately without finishing the current jobs.
 
-=head2 TTIN
+=head1 REMOTE CONTROL COMMANDS
 
-Increase the number of jobs to perform concurrently by one.
+The L<Minion::Command::minion::worker> process can be controlled at runtime
+with the following remote control commands.
 
-=head2 TTOU
+=head2 jobs
 
-Decrease the number of jobs to perform concurrently by one.
+  $ ./myapp.pl minion job -b jobs -a '[10]'
+  $ ./myapp.pl minion job -b jobs -a '[10]' 23
 
-=head2 USR1
+Change the number of jobs to perform concurrently. Setting this value to C<0>
+will effectively pause the worker. That means all current jobs will be finished,
+but no new ones accepted, until the number is increased again.
 
-Pause the worker by setting the number of jobs to perform concurrently to zero.
-That means it will finish all current jobs, but not accept new ones, until the
-number is increased again with L</"TTIN">.
+=head2 stop
+
+  $ ./myapp.pl minion job -b stop -a '[10025]'
+  $ ./myapp.pl minion job -b stop -a '[10025]' 23
+
+Stop a job that is currently being performed immediately.
 
 =head1 ATTRIBUTES
 
